"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.4.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.hyperscale_instance import HyperscaleInstance
from delphix.api.gateway.model.paginated_response_metadata import PaginatedResponseMetadata
globals()['HyperscaleInstance'] = HyperscaleInstance
globals()['PaginatedResponseMetadata'] = PaginatedResponseMetadata
from delphix.api.gateway.model.search_hyperscale_instances_response import SearchHyperscaleInstancesResponse


class TestSearchHyperscaleInstancesResponse(unittest.TestCase):
    """SearchHyperscaleInstancesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSearchHyperscaleInstancesResponse(self):
        """Test SearchHyperscaleInstancesResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SearchHyperscaleInstancesResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
